/* Help Page Styles */

.help-container {
    max-width: 900px;
    margin: 0 auto;
}

.help-section {
    background: var(--bg-card);
    border-radius: 12px;
    padding: 2rem;
    margin-bottom: 2rem;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
}

.help-section h2 {
    color: var(--text-primary);
    font-size: 1.75rem;
    margin-bottom: 1rem;
    display: flex;
    align-items: center;
    gap: 0.5rem;
}

.help-section p {
    color: var(--text-secondary);
    line-height: 1.6;
    margin-bottom: 1rem;
}

.help-section ul, .help-section ol {
    color: var(--text-secondary);
    line-height: 1.8;
    padding-left: 1.5rem;
}

.help-section li {
    margin-bottom: 0.5rem;
}

.help-section code {
    background: var(--bg-secondary);
    padding: 0.25rem 0.5rem;
    border-radius: 4px;
    font-family: 'Courier New', monospace;
    font-size: 0.9em;
    color: var(--primary);
}

.help-section strong {
    color: var(--text-primary);
    font-weight: 600;
}

.faq-item {
    margin-bottom: 2rem;
    padding-bottom: 2rem;
    border-bottom: 1px solid var(--border-color);
}

.faq-item:last-child {
    border-bottom: none;
    margin-bottom: 0;
    padding-bottom: 0;
}

.faq-item h3 {
    color: var(--text-primary);
    font-size: 1.25rem;
    margin-bottom: 0.75rem;
}

.tips-grid {
    display: grid;
    grid-template-columns: repeat(auto-fit, minmax(250px, 1fr));
    gap: 1.5rem;
    margin-top: 1.5rem;
}

.tip-card {
    background: var(--bg-secondary);
    padding: 1.5rem;
    border-radius: 10px;
    text-align: center;
    transition: all 0.3s ease;
}

.tip-card:hover {
    transform: translateY(-4px);
    box-shadow: 0 4px 12px rgba(102, 126, 234, 0.2);
}

.tip-icon {
    font-size: 2.5rem;
    display: block;
    margin-bottom: 1rem;
}

.tip-card h4 {
    color: var(--text-primary);
    font-size: 1.1rem;
    margin-bottom: 0.5rem;
}

.tip-card p {
    color: var(--text-secondary);
    font-size: 0.9rem;
    margin: 0;
}

.contact-section {
    background: linear-gradient(135deg, #667eea 0%, #764ba2 100%);
    color: white;
}

.contact-section h2 {
    color: white;
}

.contact-section p {
    color: rgba(255, 255, 255, 0.9);
}

.contact-section a {
    color: white;
    text-decoration: underline;
    font-weight: 600;
}

.contact-section a:hover {
    color: #10b981;
}

.header-with-back {
    display: flex;
    align-items: center;
    gap: 1rem;
}

.btn-back {
    display: inline-flex;
    align-items: center;
    gap: 0.5rem;
    background: rgba(99, 102, 241, 0.1);
    color: var(--primary);
    padding: 0.625rem 1.25rem;
    border-radius: 10px;
    border: 1px solid rgba(99, 102, 241, 0.2);
    text-decoration: none;
    font-weight: 500;
    font-size: 0.9rem;
    transition: all 0.3s ease;
}

.btn-back:hover {
    background: var(--primary);
    color: white;
    border-color: var(--primary);
    transform: translateX(-4px);
    box-shadow: 0 4px 12px rgba(99, 102, 241, 0.3);
}

.form-container {
    max-width: 700px;
    margin: 0 auto;
}

.card-form {
    background: var(--bg-card);
    border-radius: 12px;
    padding: 2rem;
    box-shadow: 0 2px 8px rgba(0, 0, 0, 0.1);
}

.password-input-wrapper {
    display: flex;
    gap: 0.5rem;
    align-items: center;
}

.password-input-wrapper input {
    flex: 1;
}

.password-strength-indicator {
    margin-top: 0.5rem;
}

.strength-text {
    display: block;
    font-size: 0.85rem;
    font-weight: 600;
    margin-top: 0.25rem;
}

.form-actions {
    display: flex;
    gap: 1rem;
    justify-content: flex-end;
    margin-top: 2rem;
}
