<!DOCTYPE html>
<html lang="tr">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>SafePass - Şifre Yöneticisi</title>
    <link rel="stylesheet" href="/static/css/styles.css">
</head>
<body>
    <!-- Main Content Area -->
    <main id="main-content">
        <div id="page-container"></div>
    </main>

    <!-- Scripts -->
    <script type="module" src="/static/js/app.js"></script>
</body>
</html>
